@@ -64,18 +64,18 @@ def get_contamination_metrics(largest_contigs_indexes, bam_file, cont_names, par
         if  param.orientation == 'fr' and bam_parser.is_proper_aligned_unique_outie(read):
             if read.rname in largest_contigs_indexes:
                 contamination_reads.append(abs(read.tlen)+2*param.read_len)
-                count_contamine += 1
+                count_contamine += 2
         if  param.orientation == 'rf' and bam_parser.is_proper_aligned_unique_innie(read):
             if read.rname in largest_contigs_indexes:
                 contamination_reads.append(abs(read.tlen))
-                count_contamine += 1 
+                count_contamine += 2 
         if counter >= iter_threshold:
                 break
 
     ## SMOOTH OUT contamine distribution here by removing extreme observations## 
     n_contamine = float(len(contamination_reads))
     mean_isize = 0
-    if count_contamine > 2:
+    if n_contamine > 2:
         mean_isize = sum(contamination_reads) / n_contamine
         std_dev_isize = (sum(list(map((lambda x: x ** 2 - 2 * x * mean_isize + mean_isize ** 2), contamination_reads))) / (n_contamine - 1)) ** 0.5
         print >> Information, 'Contamine mean before filtering :', mean_isize
